/*
 * Name:     CAnimChannel.cpp
 *
 *
 * Class:    CAnimChannel
 * Header:   CAnimChannel.h
 * Created : Mar 14, 2010
 * Author :  Kenji Aono
 */

#include "wx/prec.h"
#include "CAnimChannel.h"
#include "CTimeline.h"

/*
 * Name :        CAnimChannel::CAnimChannel()
 * Description : Animation channel constructor, keyframes are invalid.
 */
CAnimChannel::CAnimChannel()
{
    mKeyframe1 = -1;
    mKeyframe2 = -1;
}

/*
 * Name :        CAnimChannel::~CAnimChannel()
 * Description : Animation channel destructor.
 */
CAnimChannel::~CAnimChannel()
{
}

/*
 * Name :        CAnimChannel::GetInsertAction()
 * Description : Determine how we should insert a keyframe into our keyframe list.
 * Parameters :  none
 * Returns :     The insert action
 */
CAnimChannel::InsertActions CAnimChannel::GetInsertAction()
{
    int currFrame = GetTimeline()->GetCurrentFrame();

    if(mKeyframe1 < 0)
    {
        if(mKeyframe2 < 0)
            return Append;
        else
            return Insert;
    }

    // We know mKeyframe1 is valid
    int frame1 = GetKeyframe(mKeyframe1)->GetFrame();

    if(mKeyframe2 < 0)
    {
        if(frame1 < currFrame)
            return Append;
        else
            return Replace;
    }

    if(frame1 < currFrame)
        return Insert;
    else
        return Replace;
}

/*
 * Name :        CAnimChannel::SetKeyframeIndices()
 * Description : Ensure the keyframe indices are valid for the current time.
 *               The location pointed to by keyframe1 must be a time less than or
 *               equal to the current time and the location pointed to by keyframe2
 *               must be the next location and a location greater than the current
 *               time. Note that the time may be before or after the first or last
 *               item in the list.  We indicate that with values of -1 for the
 *               indices.
 * Parameters :  none
 * Returns :     none
 */
void CAnimChannel::SetKeyframeIndices()
{
    int currFrame = GetTimeline()->GetCurrentFrame();

    // Should we move forward in time?
    while(mKeyframe2 >= 0 && GetKeyframe(mKeyframe2)->GetFrame() <= currFrame)
    {
        mKeyframe1 = mKeyframe2;
        mKeyframe2++;
        if(mKeyframe2 >= GetNumKeyframes())
            mKeyframe2 = -1;
    }

    // Should we move backwards in time?
    while(mKeyframe1 >= 0 && GetKeyframe(mKeyframe1)->GetFrame() > currFrame)
    {
        mKeyframe2 = mKeyframe1;
        mKeyframe1--;
    }
}

