/*
 * Name:     CDrawable.h
 *
 *
 * Class:    CDrawable
 * Impl:     CDrawable.cpp
 * Created : Feb 26, 2010
 * Author :  Kenji Aono
 */

#pragma once
#ifndef CDRAWABLE_H_
#define CDRAWABLE_H_

#include "CAnimChannelAngle.h"
#include "CAnimChannelPos.h"
#include "CTimeline.h"
#include <wx/xml/xml.h>
#include <list>

class CActor;

/*
 * Class:    CDrawable
 * 
 */
class CDrawable
{
public:
	CDrawable(const std::wstring &name);
	virtual ~CDrawable();

	void Place(wxPoint offset, double rotate);
	void AddChild(CDrawable *child);
	void AddSChild(CDrawable *child);
	void XmlSaveDrawable(wxXmlNode* actor);
	virtual void Draw(wxDC *dc) = 0;

	virtual bool HitTest(wxPoint pos) = 0;
	virtual bool IsMovable();
	virtual bool IsRotatable() {return true;}
	void Move(wxPoint delta);
	void TogEnabled() {mEnabled == false ? mEnabled = true : mEnabled = false;}

	void SetPosition(wxPoint p);
	wxPoint GetPosition() const {return mPosition;}
	void SetName(const std::wstring &name) {mName = name;}
	std::wstring GetName() const {return mName;}
	virtual void SetRotation(double r);
	double GetRotation() const {return mRotation;}
	void SetActor(CActor* a);
	CActor* GetActor() const {return mActor;}
	void SetParent(CDrawable* mommy) {mParent = mommy; mDefaultRot = mRotation; mDefaultPos = mPosition;}
	CDrawable* GetParent() const {return mParent;}
	virtual void SetTimeline(CTimeline *timeline);
	virtual void SetKeyframe();
	virtual void GetKeyframe();
	void ClearKeyframe();
	void ClearChannels();
	void SetDefault() {mRotation = mDefaultRot; mPosition = mDefaultPos;}

protected:
	wxPoint RotatePoint(wxPoint point, double angle);
	double mRotation;
	wxPoint mPosition;
	bool mEnabled;
	double mDefaultRot;
	wxPoint mDefaultPos;

private:
	CDrawable();
	std::wstring mName;
	CActor* mActor;
	std::list<CDrawable *> mChildren;
	CDrawable* mParent;
    CAnimChannelAngle mChannel;
    CAnimChannelPos mChannel2;

protected:
	wxPoint mPlacedPosition;
	double mPlacedR;
};

#endif /* CDRAWABLE_H_ */
