/* Name:     CFrame.h
 *
 *
 * Class:    CFrame
 * Impl:     CFrame.cpp
 * Created : Feb 20, 2010
 * Author :  Charles B. Owen - Initial distributed version
 * Co-Author: Kenji Aono
 */

#pragma once
#ifndef CFRAME_H_
#define CFRAME_H_

#include "CViewTimeline.h"
#include "CViewEdit.h"
#include "CViewActors.h"
#include "CDocument.h"
#include <wx/xml/xml.h>

/*
 * Class:    CFrame
 * Main application frame class.
 */
class CFrame : public wxFrame
{
public:
    CFrame();
    virtual ~CFrame();

    enum Ids {ID_Exit=1, ID_None, ID_About, ID_Save, ID_Load, ID_Expand, ID_ToolBar,
              ID_Move, ID_Rotate, ID_Keyframe, ID_NoKeyframe, ID_AnimationProperties};

    void OnExit(wxCommandEvent& event);
    void OnAbout(wxCommandEvent& event);
    void OnSave(wxCommandEvent& event);
    void OnOpen(wxCommandEvent& event);
    void OnLoad(std::wstring filename);
    void SaveAnimation(const std::wstring &filename);
    void OnMove(wxCommandEvent& event);
    void OnExpand(wxCommandEvent& event);
    void OnAnimationProperties(wxCommandEvent &event);
    void OnRotate(wxCommandEvent& event);
    void OnKeyframeSet(wxCommandEvent& event);
    void OnKeyframeClear(wxCommandEvent& event);

    CDocument *GetDocument() {return mDocument;}
    CViewEdit *GetEditView() {return mViewEdit;}
    Ids GetMode() const {return mMode;}

    DECLARE_EVENT_TABLE()

private:
    void SetInterface();
    void AddToToolbar(wxToolBar *toolBar, bool checked, const std::wstring &file, int id, const std::wstring &name);

    Ids  mMode;

    wxToolBar *mToolBar;
    CViewTimeline *mViewTimeline;
    CViewEdit *mViewEdit;
    CViewActors *mViewActors;
    CDocument *mDocument;
};

#endif /* CFRAME_H_ */
