/*
 * Name:     CHaroldFactory.cpp
 *
 *
 * Class:    CHaroldFactory
 * Header:   CHaroldFactory.h
 * Created : Feb 26, 2010
 * Author :  Kenji Aono
 */

#include "wx/prec.h"
#include "CHaroldFactory.h"
#include "CPolyDrawable.h"
#include "CImageDrawable.h"
#include "CHead.h"
#include "CNoRotationImageDrawable.h"

/*
 * Name :        CHaroldFactory::CHaroldFactory()
 * Description : HaroldFactory constructor.
 */
CHaroldFactory::CHaroldFactory()
{
}

/*
 * Name :        CHaroldFactory::~CHaroldFactory()
 * Description : HaroldFactory destructor.
 */
CHaroldFactory::~CHaroldFactory()
{
}

/*
 * Name :        CHaroldFactory::Create()
 * Description : Create a Harold actor
 * Parameters :  none
 * Returns :     pointer to a CActor object populated with Harold
 */
CActor * CHaroldFactory::Create()
{
    CActor *actor = new CActor(L"Harold");

    CImageDrawable *shirt = new CImageDrawable(L"Shirt", L"images/harold_shirt.png");
    shirt->SetCenter(wxPoint(44, 138));
    shirt->SetPosition(wxPoint(0, -114));
    actor->SetRoot(shirt);

    // Use CNoRotationImageDrawable for images we don't want to be rotated
    CNoRotationImageDrawable *vest = new CNoRotationImageDrawable(L"Vest", L"images/harold_vest.png");
    vest->SetCenter(wxPoint(44, 138));
    shirt->AddChild(vest);
/*
    CImageDrawable *lleg = new CImageDrawable(L"Left Leg", L"images/harold_lleg.png");
    lleg->SetCenter(wxPoint(11, 9));
    lleg->SetPosition(wxPoint(27, 0));
    shirt->AddChild(lleg);

    CImageDrawable *rleg = new CImageDrawable(L"Right Leg", L"images/harold_rleg.png");
    rleg->SetCenter(wxPoint(39, 9));
    rleg->SetPosition(wxPoint(-27, 0));
    shirt->AddChild(rleg);
*/
    CImageDrawable *headb = new CImageDrawable(L"Head Bottom", L"images/harold_headb.png");
    headb->SetCenter(wxPoint(44,31));
    headb->SetPosition(wxPoint(0, -130));
    shirt->AddChild(headb);

    CHead *headt = new CHead(L"Head Top", L"images/harold_headt_blank.png", 1);
    headt->SetCenter(wxPoint(55, 109));
    headt->SetPosition(wxPoint(0, -31));
    headb->AddChild(headt);

    /*Note: Creating here instead of in CHead allows rotation of individual parts
    CNoRotationImageDrawable *leye = new CNoRotationImageDrawable(L"Left Eye", L"images/eye.png");
    leye->SetPosition(wxPoint(6, -36));
    headt->AddChild(leye);

    CPolyDrawable *leyeb = new CPolyDrawable(L"Left Eyebrow");
    leyeb->SetColor(wxColour(0, 0, 0));
    leyeb->SetPosition(wxPoint(6, -4));
    leyeb->AddPoint(wxPoint(-6, 2));
    leyeb->AddPoint(wxPoint(12, 2));
    leyeb->AddPoint(wxPoint(12, -1));
    leyeb->AddPoint(wxPoint(-6, -1));
    leye->AddChild(leyeb);

    CNoRotationImageDrawable *reye = new CNoRotationImageDrawable(L"Right Eye", L"images/eye.png");
    reye->SetPosition(wxPoint(-24, -36));
    headt->AddChild(reye);

    CPolyDrawable *reyeb = new CPolyDrawable(L"Right Eyebrow");
    reyeb->SetColor(wxColour(0, 0, 0));
    reyeb->SetPosition(wxPoint(12, -4));
    reyeb->AddPoint(wxPoint(-12, 2));
    reyeb->AddPoint(wxPoint(6, 2));
    reyeb->AddPoint(wxPoint(6, -1));
    reyeb->AddPoint(wxPoint(-12, -1));
    reye->AddChild(reyeb);*/

    CPolyDrawable *larm = new CPolyDrawable(L"Left Arm");
    larm->SetColor(wxColour(60, 174, 184));
    larm->SetPosition(wxPoint(50, -130));
    larm->AddPoint(wxPoint(-8, -7));
    larm->AddPoint(wxPoint(-8, 44));
    larm->AddPoint(wxPoint(8, 44));
    larm->AddPoint(wxPoint(8, -7));
    shirt->AddChild(larm);

    CPolyDrawable *rarm = new CPolyDrawable(L"Right Arm");
    rarm->SetColor(wxColour(60, 174, 184));
    rarm->SetPosition(wxPoint(-45, -130));
    rarm->AddPoint(wxPoint(-8, -7));
    rarm->AddPoint(wxPoint(-8, 44));
    rarm->AddPoint(wxPoint(8, 44));
    rarm->AddPoint(wxPoint(8, -7));
    shirt->AddChild(rarm);

    CPolyDrawable *lfarm = new CPolyDrawable(L"Left Forearm");
    lfarm->SetColor(wxColour(60, 174, 184));
    lfarm->SetPosition(wxPoint(0, 44));
    lfarm->AddPoint(wxPoint(-8, -8));
    lfarm->AddPoint(wxPoint(-8, 52));
    lfarm->AddPoint(wxPoint(8, 52));
    lfarm->AddPoint(wxPoint(8, -8));
    larm->AddChild(lfarm);

    CPolyDrawable *rfarm = new CPolyDrawable(L"Right Forearm");
    rfarm->SetColor(wxColour(60, 174, 184));
    rfarm->SetPosition(wxPoint(0, 44));
    rfarm->AddPoint(wxPoint(-8, -8));
    rfarm->AddPoint(wxPoint(-8, 52));
    rfarm->AddPoint(wxPoint(8, 52));
    rfarm->AddPoint(wxPoint(8, -8));
    rarm->AddChild(rfarm);

    CPolyDrawable *lhand = new CPolyDrawable(L"Left Hand");
    lhand->SetColor(wxColour(253, 218, 180));
    lhand->SetPosition(wxPoint(0, 52));
    lhand->AddPoint(wxPoint(-12, -9));
    lhand->AddPoint(wxPoint(-12, 11));
    lhand->AddPoint(wxPoint(11, 11));
    lhand->AddPoint(wxPoint(11, -9));
    lfarm->AddChild(lhand);

    CPolyDrawable *rhand = new CPolyDrawable(L"Right Hand");
    rhand->SetColor(wxColour(253, 218, 180));
    rhand->SetPosition(wxPoint(0, 52));
    rhand->AddPoint(wxPoint(-12, -9));
    rhand->AddPoint(wxPoint(-12, 11));
    rhand->AddPoint(wxPoint(11, 11));
    rhand->AddPoint(wxPoint(11, -9));
    rfarm->AddChild(rhand);

    CPolyDrawable *lleg = new CPolyDrawable(L"Left Leg");
    lleg->SetColor(wxColour(59,120,125));
    lleg->SetPosition(wxPoint(27,0));
    lleg->AddPoint(wxPoint(-13, -14));
    lleg->AddPoint(wxPoint(-13, 52));
    lleg->AddPoint(wxPoint(14, 52));
    lleg->AddPoint(wxPoint(14, -14));
    shirt->AddChild(lleg);

    CPolyDrawable *rleg = new CPolyDrawable(L"Right Leg");
    rleg->SetColor(wxColour(59,120,125));
    rleg->SetPosition(wxPoint(-27,0));
    rleg->AddPoint(wxPoint(-14, -14));
    rleg->AddPoint(wxPoint(-14, 52));
    rleg->AddPoint(wxPoint(13, 52));
    rleg->AddPoint(wxPoint(13, -14));
    shirt->AddChild(rleg);

    CPolyDrawable *lshin = new CPolyDrawable(L"Left Shin");
    lshin->SetColor(wxColour(59,120,125));
    lshin->SetPosition(wxPoint(0,50));
    lshin->AddPoint(wxPoint(-14, -14));
    lshin->AddPoint(wxPoint(-14, 55));
    lshin->AddPoint(wxPoint(13, 55));
    lshin->AddPoint(wxPoint(13, -14));
    lleg->AddChild(lshin);

    CPolyDrawable *rshin = new CPolyDrawable(L"Right Shin");
    rshin->SetColor(wxColour(59,120,125));
    rshin->SetPosition(wxPoint(0,50));
    rshin->AddPoint(wxPoint(-14, -14));
    rshin->AddPoint(wxPoint(-14, 55));
    rshin->AddPoint(wxPoint(13, 55));
    rshin->AddPoint(wxPoint(13, -14));
    rleg->AddChild(rshin);

    CPolyDrawable *lfoot = new CPolyDrawable(L"Left Foot");
    lfoot->SetColor(wxColour(0,0,0));
    lfoot->SetPosition(wxPoint(-6,52));
    lfoot->AddPoint(wxPoint(44, -3));
    lfoot->AddPoint(wxPoint(44, 13));
    lfoot->AddPoint(wxPoint(-8, 13));
    lfoot->AddPoint(wxPoint(-8, -3));
    lshin->AddChild(lfoot);

    CPolyDrawable *rfoot = new CPolyDrawable(L"Right Foot");
    rfoot->SetColor(wxColour(0,0,0));
    rfoot->SetPosition(wxPoint(6,52));
    rfoot->AddPoint(wxPoint(8, -3));
    rfoot->AddPoint(wxPoint(8, 13));
    rfoot->AddPoint(wxPoint(-44, 13));
    rfoot->AddPoint(wxPoint(-44, -3));
    rshin->AddChild(rfoot);

    actor->AddDrawable(rleg);
    actor->AddDrawable(rshin);
    actor->AddDrawable(rfoot);
    actor->AddDrawable(lleg);
    actor->AddDrawable(lshin);
    actor->AddDrawable(lfoot);
    actor->AddDrawable(shirt);
    actor->AddDrawable(vest);
    actor->AddDrawable(headb);
    actor->AddDrawable(headt);
    actor->AddDrawable(rarm);
    actor->AddDrawable(larm);
    actor->AddDrawable(rfarm);
    actor->AddDrawable(lfarm);
    actor->AddDrawable(rhand);
    actor->AddDrawable(lhand);

    return actor;
}
