/*
 * Name:     CHead.cpp
 *
 *
 * Class:    CHead
 * Header:   CHead.h
 * Created : Feb 26, 2010
 * Author :  Kenji Aono
 */

#include "wx/prec.h"
#include "CHead.h"
#include "CNoRotationImageDrawable.h"
#include "CPolyDrawable.h"

/*
 * Name :        CHead::CHead()
 * Description : Head (ImagedDrawable) class constructor.
 */
//CHead::CHead()
//{
//}

/*
 * Name :        CHead::CHead()
 * Description : Constructor for an image-based drawable of a head.
 */

CHead::CHead(const std::wstring &name, const std::wstring &filename, int indicator) : CImageDrawable(name, filename)
{
	mClass = indicator-1;

	// This make more sense if all eyes/eyebrows are the same no matter the head type
    if (mClass == Harold)
    {
		CNoRotationImageDrawable *leye = new CNoRotationImageDrawable(L"Left Eye", L"images/eye.png");
		leye->SetCenter(mCenter);
		leye->SetPosition(wxPoint(6, -36));
		this->AddSChild(leye);

		CPolyDrawable *leyeb = new CPolyDrawable(L"Left Eyebrow");
		leyeb->SetColor(wxColour(0, 0, 0));
		leyeb->SetPosition(wxPoint(6, -4));
		leyeb->AddPoint(wxPoint(-6, 2));
		leyeb->AddPoint(wxPoint(12, 2));
		leyeb->AddPoint(wxPoint(12, -1));
		leyeb->AddPoint(wxPoint(-6, -1));
		leye->AddSChild(leyeb);

		CNoRotationImageDrawable *reye = new CNoRotationImageDrawable(L"Right Eye", L"images/eye.png");
		reye->SetPosition(wxPoint(-24, -36));
		this->AddSChild(reye);

		CPolyDrawable *reyeb = new CPolyDrawable(L"Right Eyebrow");
		reyeb->SetColor(wxColour(0, 0, 0));
		reyeb->SetPosition(wxPoint(12, -4));
		reyeb->AddPoint(wxPoint(-12, 2));
		reyeb->AddPoint(wxPoint(6, 2));
		reyeb->AddPoint(wxPoint(6, -1));
		reyeb->AddPoint(wxPoint(-12, -1));
		reye->AddSChild(reyeb);

		mDrawables.push_back(leye);
		mDrawables.push_back(leyeb);
		mDrawables.push_back(reye);
		mDrawables.push_back(reyeb);
	}
    else if (mClass == DanishCousin)
	{
		CNoRotationImageDrawable *eyes = new CNoRotationImageDrawable(L"Eyes", L"images/danish_cousin_eyes.png");
		eyes->SetCenter(wxPoint(56, 18));
		eyes->SetPosition(wxPoint(0, -30));
		this->AddSChild(eyes);

		CPolyDrawable *reyeb = new CPolyDrawable(L"Right Eyebrow");
		reyeb->SetColor(wxColour(0, 0, 0));
		reyeb->SetPosition(wxPoint(-14, -18));
		reyeb->AddPoint(wxPoint(-16,2));
		reyeb->AddPoint(wxPoint(-12, 1));
		reyeb->AddPoint(wxPoint(6, 1));
		reyeb->AddPoint(wxPoint(6, -1));
		reyeb->AddPoint(wxPoint(-12, -1));
		reyeb->AddPoint(wxPoint(-14,4));
		eyes->AddSChild(reyeb);

		CPolyDrawable *leyeb = new CPolyDrawable(L"Left Eyebrow");
		leyeb->SetColor(wxColour(0, 0, 0));
		leyeb->SetPosition(wxPoint(10, -18));
		leyeb->AddPoint(wxPoint(16,2));
		leyeb->AddPoint(wxPoint(12, 1));
		leyeb->AddPoint(wxPoint(-6, 1));
		leyeb->AddPoint(wxPoint(-6, -1));
		leyeb->AddPoint(wxPoint(12, -1));
		leyeb->AddPoint(wxPoint(14,4));
		eyes->AddSChild(leyeb);

		mDrawables.push_back(eyes);
		mDrawables.push_back(leyeb);
		mDrawables.push_back(reyeb);
	}

	mImage.LoadFile(filename.c_str());
	SetCenter(wxPoint(0, 0));
}

/*
 * Name :        CHead::~CHead()
 * Description : Head (ImagedDrawable) class destructor.
 */
CHead::~CHead()
{
}

/*
 * Name :        CHead::Draw()
 * Description : Draw the drawable image.
 * Parameters :  dc - Device context
 * Returns :     none
 */
void CHead::Draw(wxDC *dc)
{
    // Don't draw if not enabled
    if(!mEnabled)
        return;

	// Draw the base for the head
	CImageDrawable::Draw(dc);

	// Draw other parts of the head
    for(std::list<CDrawable *>::iterator d=mDrawables.begin(); d!=mDrawables.end(); d++)
    {
        CDrawable *drawable = *d;
        drawable->Draw(dc);
    }
}
