/*
 * Name:     CTimeline.cpp
 *
 *
 * Class:    CTimeline
 * Header:   CTimeline.h
 * Created : Mar 10, 2010
 * Author :  Kenji Aono
 */

#include "wx/prec.h"
#include "CTimeline.h"

/*
 * Name :        CTimeline::CTimeline()
 * Description : Constructor for a timeline object.
 * Parameters :  name - The name of the object we are creating.
 * Returns :     none
 */
CTimeline::CTimeline()
{
	mNumFrames = 300;
	mFrameRate = 30;
	mCurrentTime = 0;
}

/*
 * Name :        CTimeline::~CTimeline()
 * Description : Destructor for a timeline object.
 * Parameters :  name - The name of the object we are creating.
 * Returns :     none
 */
CTimeline::~CTimeline()
{
}

/*
 * Name :        CTimeline::AddChannel()
 * Description : Add a channel to the timeline
 * Parameters :  A pointer to the channel being added
 * Returns :     none
 */
void CTimeline::AddChannel(CAnimChannel *channel)
{
	mChannels.push_back(channel);
	channel->SetTimeline(this);
}

/*
 * Name :        CTimeline::SetCurrentTime()
 * Description : Sets the current time and ensures all of the channels are
 *               valid for that point in time.
 * Parameters :  none
 * Returns :     none
 */
void CTimeline::SetCurrentTime(double t)
{
    // Set the time
    mCurrentTime = t;

    for(std::vector<CAnimChannel *>::iterator c=mChannels.begin(); c!=mChannels.end(); c++)
    {
        (*c)->SetKeyframeIndices();
    }
}

/*
 * Name :        CTimeline::CutChannel()
 * Description : Cuts the channel after the given frame
 * Parameters :  Frame to ignore keyframes after
 * Returns :     none
 */
void CTimeline::CutChannel(unsigned int numFrames)
{
	SetCurrentTime(numFrames / mFrameRate);
	unsigned int i = GetCurrentFrame();
	while (i <= mNumFrames)
	{
		for(std::vector<CAnimChannel *>::iterator iterChan=mChannels.begin(); iterChan!=mChannels.end(); iterChan++)
		{
			CAnimChannel *channel = *iterChan;
			channel->ClearKeyframe();
		}
		i++;
		SetCurrentTime(double(i) / double(mFrameRate));
	}
}
